Crate pdfluent_lopdf

Crate pdfluent_lopdf 

lopdf — PDF document manipulation library (forked for XFA project).

Re-exports

pub use encryption::EncryptionState;
pub use encryption::EncryptionVersion;
pub use encryption::Permissions;
pub use encryption::aes256_encryption_state;

Modules

content
encryption
filters
xobject
xref

Macros

dictionary

Structs

Bookmark
Destination
Dictionary
Dictionary object.
Document
A PDF document.
FontData
This struct represents the data of a font. It contains information about the font’s bounding box, ascent, descent, cap height, italic angle, and stemV. Reference: https://opensource.adobe.com/dc-acrobat-sdk-docs/pdfstandards/pdfreference1.5_v6.pdf
IncrementalDocument
LoadOptions
Options that control how a PDF document is loaded into memory.
ObjectStream
ObjectStreamBuilder
ObjectStreamConfig
PdfMetadata
PDF metadata extracted without loading the entire document. This is useful for quickly getting basic information about large PDFs.
Reader
SaveOptions
Options for saving PDF documents
SaveOptionsBuilder
Builder for SaveOptions
Stream
Stream object Warning - all streams must be indirect objects, while the stream dictionary may be a direct object
Toc

Enums

Encoding
Error
Object
Basic PDF object types defined in an enum.
Outline
StringFormat
String objects can be written in two formats.

Constants

DEFAULT_MAX_FILE_BYTES
Default maximum input size: 256 MiB.

Functions

decode_text_string
Decodes a text string. Depending on the BOM at the start of the string, a different encoding is chosen. All encodings specified in PDF2.0 are supported (PDFDocEncoding, UTF-16BE, and UTF-8).
encode_utf8
Encodes the given str to UTF-8. This method of encoding text strings is first specified in PDF2.0 and reader support is still lacking (notably, Adobe Acrobat Reader doesn’t support it at the time of writing). Thus, using it is NOT RECOMMENDED.
encode_utf16_be
Encodes the given str to UTF-16BE. The recommended way to encode text strings, as it supports all of unicode and all major PDF readers support it.
substr
substring
text_string
Creates a text string. If the input only contains ASCII characters, the string is encoded in PDFDocEncoding, otherwise in UTF-16BE.

Type Aliases

ObjectId
Object identifier consists of two parts: object number and generation number.
Result