IncrementalDocument

Struct IncrementalDocument 

pub struct IncrementalDocument {
    pub new_document: Document,
    /* private fields */
}

Fields

new_document: Document

A new document appended to the previously loaded file.

Implementations

Source

impl IncrementalDocument

pub fn new() -> Self

Create new PDF document.

pub fn create_from(prev_bytes: Vec<u8>, prev_documents: Document) -> Self

Create new IncrementalDocument from the bytes and document.

The function expects the bytes and previous document to match. If they do not match exactly this might result in broken PDFs.

pub fn get_prev_documents(&self) -> &Document

Get the structure of the previous documents (all prev incremental updates combined.)

pub fn get_prev_documents_bytes(&self) -> &[u8]

Get the bytes of the previous documents.

pub fn opt_clone_object_to_new_document( &mut self, object_id: ObjectId, ) -> Result<()>

Clone Object from previous document to new document. If the object already exists nothing is done.

This function can be used to clone an object so it can be changed in the incremental updates.

pub fn get_or_create_resources( &mut self, page_id: ObjectId, ) -> Result<&mut Object>

Get the page’s resource dictionary (only in new document).

Get Object that has the key Resources.

pub fn add_xobject<N: Into<Vec<u8>>>( &mut self, page_id: ObjectId, xobject_name: N, xobject_id: ObjectId, ) -> Result<()>

Add XObject to a page.

Get Object that has the key Resources -> XObject.

pub fn add_graphics_state<N: Into<Vec<u8>>>( &mut self, page_id: ObjectId, gs_name: N, gs_id: ObjectId, ) -> Result<()>

Add Graphics State to a page.

Get Object that has the key Resources -> ExtGState.

Source

impl IncrementalDocument

pub fn save<P: AsRef<Path>>(&mut self, path: P) -> Result<File>

Save PDF document to specified file path.

pub fn save_to<W: Write>(&mut self, target: &mut W) -> Result<()>

Save PDF to arbitrary target

Source

impl IncrementalDocument

pub async fn load<P: AsRef<Path>>(path: P) -> Result<Self>

Load a PDF document from a specified file path.

pub async fn load_from<R: AsyncRead>(source: R) -> Result<Self>

Load a PDF document from an arbitrary source.

pub fn load_mem(buffer: &[u8]) -> Result<Document>

Load a PDF document from a memory slice.